aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rwxr-xr-xsrc/scripts/ci/travis/install.sh7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/scripts/ci/travis/install.sh b/src/scripts/ci/travis/install.sh
index 9cbd65c83..c076a25ae 100755
--- a/src/scripts/ci/travis/install.sh
+++ b/src/scripts/ci/travis/install.sh
@@ -23,8 +23,11 @@ if [ "$TRAVIS_OS_NAME" = "linux" ]; then
if [ "$BUILD_MODE" = "docs" ]; then
sudo apt-get install doxygen
- # The version of Sphinx in 14.04 is too old (1.2.2)
- # and does not support all C++ features used in the manual
+
+ # The version of Sphinx in 14.04 is too old (1.2.2) and does not support
+ # all C++ features used in the manual. Install python-requests to avoid
+ # strange Ubuntu bug http://stackoverflow.com/questions/32779919/no-module-named-for-requests
+ sudo apt-get install python-requests
sudo pip install sphinx
fi